package cn.bunny.file;

import org.junit.jupiter.api.Test;

import java.io.*;
import java.nio.channels.FileChannel;
import java.time.Duration;
import java.time.LocalDateTime;

public class FileTest {
    /**
     * * 读取和写入纯文本内容
     */
    @Test
    void paintTextTest() {
        // 源文件路径
        String source = "D:\\dir\\source\\plain text.md";
        // 目标文件路径
        String target = "D:\\dir\\target\\plain text.md";

        try (
                // 创建读取和写入流
                BufferedReader reader = new BufferedReader(new FileReader(source));
                BufferedWriter writer = new BufferedWriter(new FileWriter(target))
        ) {
            // 读取源文件并写入目标文件
            String line = reader.readLine();
            while (line != null) {
                writer.write(line);
                writer.newLine();
                line = reader.readLine();
            }
        } catch (IOException exception) {
            System.out.println(exception.getMessage());
        }
    }

    /**
     * * 读取和写入流媒体内容
     */
    @Test
    void streamMediaTest() {
        // 开始复制时间
        LocalDateTime start = LocalDateTime.now();

        // 源文件路径
        String sourcePath = "D:\\dir\\source\\video.ts";
        // 目标文件路径
        String targetPath = "D:\\dir\\target\\video.ts";

        try (
                // 创建FileInputStream来读取源文件
                FileInputStream reader = new FileInputStream(sourcePath);
                // 创建BufferedWriter来写入目标文件
                FileOutputStream writer = new FileOutputStream(targetPath)
        ) {
            // 创建缓冲区
            byte[] buffer = new byte[1024 * 7];
            int length;

            // 读取源文件并写入目标文件
            while ((length = reader.read(buffer)) > 0) writer.write(buffer, 0, length);

        } catch (IOException exception) {
            System.out.println(exception.getMessage());
        }

        // 计算时间差
        LocalDateTime end = LocalDateTime.now();
        Duration duration = Duration.between(start, end);
        System.out.println("复制耗时: " + duration.toMillis() + " 毫秒");// 复制耗时: 614 毫秒
    }

    /**
     * * 使用NIO
     */
    @Test
    void nioStreamMediaTest() {
        // 开始复制时间
        LocalDateTime start = LocalDateTime.now();

        // 源文件路径
        String sourcePath = "D:\\dir\\source\\video.ts";
        // 目标文件路径
        String targetPath = "D:\\dir\\target\\video.ts";

        try (
                FileInputStream inputStream = new FileInputStream(sourcePath);
                FileOutputStream outputStream = new FileOutputStream(targetPath);
                FileChannel sourceChannel = inputStream.getChannel();
                FileChannel targetChannel = outputStream.getChannel()
        ) {
            long position = 0;
            long count = sourceChannel.size();

            while (position < count) {
                position += sourceChannel.transferTo(position, count - position, targetChannel);
            }
        } catch (IOException exception) {
            System.out.println(exception.getMessage());
        }

        // 计算时间差
        LocalDateTime end = LocalDateTime.now();
        Duration duration = Duration.between(start, end);
        System.out.println("复制耗时: " + duration.toMillis() + " 毫秒");// 复制耗时: 325 毫秒
    }
}
