package cn.bunny.http;

import lombok.SneakyThrows;

import java.net.URI;
import java.net.http.HttpClient;
import java.net.http.HttpRequest;
import java.net.http.HttpResponse;
import java.util.Optional;
import java.util.concurrent.CompletableFuture;
import java.util.concurrent.Executor;

public class HttpClientTest {
    // 同步发送HTTP请求
    private static void sendSyncRequest(HttpClient httpClient, String URL) throws Exception {
        HttpRequest request = HttpRequest.newBuilder()
                .uri(new URI(URL))
                .GET()
                .build();

        HttpResponse<String> response = httpClient.send(request, HttpResponse.BodyHandlers.ofString());

        System.out.println("Response status code: " + response.statusCode());
        System.out.println("Response body: " + response.body());
        System.out.println("Response header: " + response.headers());
    }

    // 异步发送HTTP请求
    private static void sendAsyncRequest(HttpClient httpClient, String URL) {
        HttpRequest request = HttpRequest.newBuilder()
                .uri(URI.create(URL))
                .GET()
                .build();

        CompletableFuture<HttpResponse<String>> future = httpClient.sendAsync(request, HttpResponse.BodyHandlers.ofString());

        future.thenAccept(response -> {
            System.out.println("Async Response status code: " + response.statusCode());
            System.out.println("Async Response body: " + response.body());
        }).join(); // 等待异步请求完成
    }

    // 设置重定向策略
    private static void setRedirectPolicy(HttpClient httpClient) {
        // 设置自动重定向策略
        HttpClient.Redirect newClient = httpClient.followRedirects();
        // 使用newClient继续发送请求
    }

    // 设置自定义执行器
    private static void setExecutor(HttpClient httpClient) {
        // 设置自定义执行器
        Optional<Executor> newClient = httpClient.executor(); // 可以传入自定义的Executor
        // 使用newClient继续发送请求
    }

    @SneakyThrows
    public static void main(String[] args) {
        String URL = "https://www.itxst.com/sortablejs/neuinffi.html";

        // 创建HttpClient对象
        HttpClient httpClient = HttpClient.newHttpClient();

        // 同步发送HTTP请求
        sendSyncRequest(httpClient, URL);

        // 异步发送HTTP请求
        sendAsyncRequest(httpClient, URL);

        // 设置重定向策略
        setRedirectPolicy(httpClient);

        // 设置自定义执行器
        setExecutor(httpClient);

        httpClient.close();
    }
}
