package cn.bunny.stream;

import lombok.SneakyThrows;
import org.junit.jupiter.api.Test;

import java.io.FileInputStream;
import java.io.InputStream;
import java.util.Arrays;

public class InputStreamTest {
    @SneakyThrows
    @Test
    void testInputStream() {
        InputStream inputStream = new FileInputStream("D:\\MyFolder\\文档和软件\\图片.zip");

        // read()方法从输入流中读取下一个字节，并返回读取的字节数据（以整数形式）。如果已到达流的末尾，则返回 -1。这个方法通常用于逐字节地读取数据。
        int read = inputStream.read();
        System.out.println(read);

        // 读取所有字节
        byte[] bytes = inputStream.readAllBytes();
        System.out.println(Arrays.toString(bytes));

        // 处理每个字节的数据
        int byteRead;
        while ((byteRead = inputStream.read()) != -1) {
            System.out.println(byteRead);
        }

        // skip(long n)方法跳过并丢弃输入流中的 n 个字节数据，并返回实际跳过的字节数。这对于跳过文件中一些特定字节的数据很有用。
        long bytesSkipped = inputStream.skip(10);
        System.out.println(bytesSkipped);

        // available()方法返回当前可从输入流中读取的字节数。这个方法通常用于检查流中是否还有未读取的数据。
        int bytesAvailable = inputStream.available();
        System.out.println(bytesAvailable);

        // close()方法关闭输入流并释放与之关联的任何系统资源。在使用完输入流后调用此方法是非常重要的，以避免资源泄漏和系统资源的浪费。
        inputStream.close();
    }
}
